==> thunderbird-6.0.2.source.tar.bz2: comm-release/mozilla/js/src/tests/ecma/ObjectObjects/15.2.2.2.js <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */


/**
   File Name:          15.2.2.2.js
   ECMA Section:       15.2.2.2 new Object()
   Description:

   When the Object constructor is called with no argument, the following
   step is taken:

   1.  Create a new native ECMAScript object.
   The [[Prototype]] property of the newly constructed object is set to
   the Object prototype object.

   The [[Class]] property of the newly constructed object is set
   to "Object".

   The newly constructed object has no [[Value]] property.

   Return the newly created native object.

   Author:             christine@netscape.com
   Date:               7 october 1997
*/
var SECTION = "15.2.2.2";
var VERSION = "ECMA_1";
startTest();
var TITLE   = "new Object()";

writeHeaderToLog( SECTION + " "+ TITLE);

new TestCase( SECTION, "typeof new Object()",   "object",       typeof new Object() );
new TestCase( SECTION, "Object.prototype.toString()",   "[object Object]",  Object.prototype.toString() );
new TestCase( SECTION, "(new Object()).toString()",  "[object Object]",   (new Object()).toString() );

test();

==> thunderbird-10.0.1.source.tar.bz2: comm-release/mozilla/js/src/tests/ecma/ObjectObjects/15.2.3.js <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */


/**
   File Name:          15.2.3.js
   ECMA Section:       15.2.3 Properties of the Object Constructor

   Description:        The value of the internal [[Prototype]] property of the
   Object constructor is the Function prototype object.

   Besides the call and construct propreties and the length
   property, the Object constructor has properties described
   in 15.2.3.1.

   Author:             christine@netscape.com
   Date:               28 october 1997

*/

var SECTION = "15.2.3";
var VERSION = "ECMA_1";
startTest();
var TITLE   = "Properties of the Object Constructor";

writeHeaderToLog( SECTION + " " + TITLE);

//    new TestCase( SECTION,  "Object.__proto__",     Function.prototype,     Object.__proto__ );
new TestCase( SECTION,  "Object.length",        1,                      Object.length );

test();
